@@ -4,11 +4,10 @@ rocks_trees = {
    { name = "user", root = home .. "/.luarocks" };
    { name = "system", root = "/usr/local" };
 }
+lua_interpreter = "lua54";
 variables = {
    LUA_DIR = "/usr/local";
-   LUA_INCDIR = "/usr/local/include/lua-5.3";
+   LUA_INCDIR = "/usr/local/include/lua-5.4";
    LUA_BINDIR = "/usr/local/bin";
    LUA_LIBDIR = "/usr/local/lib";
-   LUA_VERSION = "5.3";
-   LUA = "/usr/local/bin/lua53";
 }
